@@ -64,7 +64,7 @@
 #'   (or decreased) after one click of the + (or -) button in the parameter
 #'   window.
 #' @param arrow A logical scalar.  Should an arrow be included to show the
-#'   simulated sample maximum from the top plot being placed into the
+#'   simulated sample mean from the top plot being placed into the
 #'   bottom plot?
 #' @param leg_cex The argument \code{cex} to \code{\link[graphics]{legend}}.
 #'   Allows the size of the legend to be controlled manually.
@@ -77,7 +77,7 @@
 #'   \href{https://en.wikipedia.org/wiki/Central_limit_theorem}{Central Limit Theorem}
 #'   is that the mean of a \strong{large number} of independent and
 #'   identically distributed random variables, each with mean \eqn{\mu} and
-#'   finite standard deviation \eqn{\sigma} has \strong{approximately} a
+#'   finite standard deviation \eqn{\sigma}, has \strong{approximately} a
 #'   normal distribution, even if these original variables are not normally
 #'   distributed.
 #'
@@ -99,26 +99,27 @@
 #'
 #'   The p.d.f. (for a continuous variable) or p.m.f. (for a discrete variable)
 #'   of the original variables is added to the top plot.
-#'   There is a checkbox to add to the bottom plot the approximate (large
-#'   \code{n}) normal p.d.f./c.d.f. (with mean \eqn{\mu} and standard
-#'   deviation \eqn{\sigma / \sqrt{n}}), implied by the CLT.
 #'
 #'   Once it starts, four aspects of this movie are controlled by the user.
 #'   \itemize{
 #'     \item{}{There are buttons to increase (+) or decrease (-) the sample
-#'       size, that is, the number of values over which a maximum is
+#'       size, that is, the number of values over which a mean is
 #'       calculated.}
 #'     \item{}{Each time the button labelled "simulate another \code{n_add}
 #'       samples of size n" is clicked \code{n_add} new samples are simulated
 #'       and their sample mean are added to the bottom histogram.}
 #'     \item{}{There is a button to switch the bottom plot from displaying
 #'       a histogram of the simulated means and the limiting normal p.d.f. to
-#'       the empirical c.d.f. of the simulated data, the exact c.d.f. and the
-#'       limiting normal c.d.f.}
+#'       the empirical c.d.f. of the simulated data and the limiting normal
+#'       c.d.f.}
+#'     \item{}{There is a checkbox to add to the bottom plot the approximate
+#'       (large \code{n}) normal p.d.f./c.d.f. (with mean \eqn{\mu} and
+#'       standard deviation \eqn{\sigma / \sqrt{n}}), implied by the CLT.}
 #'   }
 #' @return Nothing is returned, only the animation is produced.
 #' @seealso \code{\link{movies}}: a user-friendly menu panel.
 #' @seealso \code{\link{smovie}}: general information about smovie.
+#' @seealso \code{\link{cltq}}: Central Limit Theorem for sample quantiles.
 #' @examples
 #' # Exponential data
 #' clt()
@@ -479,10 +480,12 @@ clt <- function(n = 20, distn, params = list(), panel_plot = TRUE, hscale = NA,
   return(invisible())
 }
 
-# Function to be called by ett().
+# Function to be called by clt().
 
 cltmovie_plot <- function(panel) {
-  old_par <- graphics::par(no.readonly = TRUE)
+  oldpar <- graphics::par(mfrow = c(2, 1), oma = c(0, 0, 0, 0),
+                          mar = c(4, 4, 2, 2) + 0.1)
+  on.exit(graphics::par(oldpar))
   # To please R CMD check
   n <- distn <- fun_args <- pdf_or_cdf <- show_dens <- n_add <- rfun <-
     discrete_distn <- top_range <- dfun <- xlab <- top_leg_pos <- arrow <-
@@ -494,8 +497,6 @@ cltmovie_plot <- function(panel) {
     } else {
       show_rug <- TRUE
     }
-    graphics::par(mfrow = c(2, 1), oma = c(0, 0, 0, 0),
-                  mar = c(4, 4, 2, 2) + 0.1)
     # Do the simulation (if required)
     if (distn == "hypergeometric") {
       sim_list <- c(list(nn = n), fun_args)
@@ -705,6 +706,5 @@ cltmovie_plot <- function(panel) {
     old_pdf_or_cdf <- pdf_or_cdf
     old_show_dens <- show_dens
   })
-  graphics::par(old_par)
   return(panel)
 }
