@@ -323,7 +323,6 @@ continuous <- function(distn, var_range = NULL, params = list(),
 }
 
 plot_continuous <- function(panel) {
-  old_par <- graphics::par(no.readonly = TRUE)
   with(panel, {
     # Put the parameter values in a named list
     new_fun_args <- list()
@@ -421,6 +420,5 @@ plot_continuous <- function(panel) {
     for_plot <- c(list(x = var_range, y = probs, type = "l"), plot_par)
     do.call(graphics::plot, for_plot)
   })
-  graphics::par(old_par)
   return(panel)
 }
